import {
  Controller,
  Get,
  Header,
  HttpCode,
  Query,
  Post,
  Body
} from '@nestjs/common'

import { AgentServerService } from './agent-server.service'
import {
  GetStaffProfileDto,
  ListUsersDto,
  GetDialogueHistoryDto,
  RunPromptDto
} from './dto'

interface ApiResponse<T> {
  code: number
  msg: string
  data: T | null
}

@Controller('agentServer')
export class AgentServerController {
  constructor(private readonly agentServerService: AgentServerService) {}

  private handleResponse<T>(response: {
    data: T
    code: number
    msg: string
  }): ApiResponse<T> {
    if (response.code === 200) {
      return {
        code: 0,
        msg: '请求成功',
        data: response.data
      }
    }
    return {
      code: 1,
      msg: response.msg,
      data: null
    }
  }

  // 获取所有员工列表
  @Get('listStaffs')
  @Header('Access-Control-Allow-Origin', '*')
  @HttpCode(200)
  async listStaffs() {
    const response = await this.agentServerService.listStaffs()
    return this.handleResponse(response)
  }

  // 获取员工详情
  @Get('getStaffProfile')
  @Header('Access-Control-Allow-Origin', '*')
  @HttpCode(200)
  async getStaffProfile(@Query() getStaffProfileDto: GetStaffProfileDto) {
    const response = await this.agentServerService.getStaffProfile(
      getStaffProfileDto.staff_id
    )
    return this.handleResponse(response)
  }

  // 获取用户详情
  @Get('getUserProfile')
  @Header('Access-Control-Allow-Origin', '*')
  @HttpCode(200)
  async getUserProfile(@Query() listUsersDto: ListUsersDto) {
    const response = await this.agentServerService.getUserProfile(
      listUsersDto.user_union_id
    )
    return this.handleResponse(response)
  }

  // 获取所有用户列表(根据用户名和用户union_id)
  @Get('listUsers')
  @Header('Access-Control-Allow-Origin', '*')
  @HttpCode(200)
  async listUsers(@Query() listUsersDto: ListUsersDto) {
    const response = await this.agentServerService.listUsers(
      listUsersDto.user_name,
      listUsersDto.user_union_id
    )
    return this.handleResponse(response)
  }

  @Get('getDialogueHistory')
  @Header('Access-Control-Allow-Origin', '*')
  @HttpCode(200)
  async getDialogueHistory(
    @Query() getDialogueHistoryDto: GetDialogueHistoryDto
  ) {
    const response = await this.agentServerService.getDialogueHistory(
      getDialogueHistoryDto.staff_id,
      getDialogueHistoryDto.user_id,
      getDialogueHistoryDto.recent_minutes
    )
    return this.handleResponse(response)
  }

  @Get('listModels')
  @Header('Access-Control-Allow-Origin', '*')
  @HttpCode(200)
  async listModels() {
    const response = await this.agentServerService.listModels()
    return this.handleResponse(response)
  }

  @Get('listScenes')
  @Header('Access-Control-Allow-Origin', '*')
  @HttpCode(200)
  async listScenes() {
    const response = await this.agentServerService.listScenes()
    return this.handleResponse(response)
  }

  @Get('getBasePrompt')
  @Header('Access-Control-Allow-Origin', '*')
  @HttpCode(200)
  async getBasePrompt() {
    const response = await this.agentServerService.getBasePrompt()
    return this.handleResponse(response)
  }

  @Post('runPrompt')
  @Header('Access-Control-Allow-Origin', '*')
  @HttpCode(200)
  async runPrompt(@Body() runPromptDto: RunPromptDto) {
    const response = await this.agentServerService.runPrompt(runPromptDto)
    return this.handleResponse(response)
  }
}
